@@ -1,4 +1,4 @@
-package Slack::BlockKit::Block::RichText::Channel 0.002;
+package Slack::BlockKit::Block::RichText::Channel 0.003;
 # ABSTRACT: a Block Kit rich text element that mentions a #channel
 
 use Moose;
@@ -58,7 +58,7 @@ Slack::BlockKit::Block::RichText::Channel - a Block Kit rich text element that m
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 OVERVIEW
 
@@ -95,7 +95,7 @@ generally a bunch of alphanumeric characters beginning with C<C>.
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@semiotic.systems>
+Ricardo SIGNES <cpan@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
