@@ -1,4 +1,4 @@
-package Slack::BlockKit::Block::RichText::Emoji 0.002;
+package Slack::BlockKit::Block::RichText::Emoji 0.003;
 # ABSTRACT: a Block Kit rich text element for a :colon_code: emoji
 
 use Moose;
@@ -54,7 +54,7 @@ Slack::BlockKit::Block::RichText::Emoji - a Block Kit rich text element for a :c
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 OVERVIEW
 
@@ -89,7 +89,7 @@ as text inside colons.
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@semiotic.systems>
+Ricardo SIGNES <cpan@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
