@@ -1,4 +1,4 @@
-package Slack::BlockKit::Block::RichText::User 0.002;
+package Slack::BlockKit::Block::RichText::User 0.003;
 # ABSTRACT: a Block Kit rich text element that mentions a @user
 
 use Moose;
@@ -58,7 +58,7 @@ Slack::BlockKit::Block::RichText::User - a Block Kit rich text element that ment
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 OVERVIEW
 
@@ -95,7 +95,7 @@ a bunch of alphanumeric characters beginning with C<U>.
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@semiotic.systems>
+Ricardo SIGNES <cpan@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
