@@ -1,4 +1,4 @@
-package Slack::BlockKit::Block::RichText::UserGroup 0.002;
+package Slack::BlockKit::Block::RichText::UserGroup 0.003;
 # ABSTRACT: a Block Kit rich text element that mentions a @usergroup
 
 use Moose;
@@ -59,7 +59,7 @@ Slack::BlockKit::Block::RichText::UserGroup - a Block Kit rich text element that
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 OVERVIEW
 
@@ -97,7 +97,7 @@ generally a bunch of alphanumeric characters beginning with C<S>.
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@semiotic.systems>
+Ricardo SIGNES <cpan@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
