@@ -1,4 +1,4 @@
-package Slack::BlockKit::CompObj::Text 0.002;
+package Slack::BlockKit::CompObj::Text 0.003;
 # ABSTRACT: a Block Kit "composition object" for text
 use Moose;
 use MooseX::StrictConstructor;
@@ -103,7 +103,7 @@ Slack::BlockKit::CompObj::Text - a Block Kit "composition object" for text
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 OVERVIEW
 
@@ -149,7 +149,7 @@ C<plain_text> object will raise an exception.
 
 =head1 AUTHOR
 
-Ricardo SIGNES <rjbs@semiotic.systems>
+Ricardo SIGNES <cpan@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
